/**************************************************************************************************
* File: MP3_driver.c
* File Type: C - Source Code File
* (C) mikroElektronika, 2012
* Revision History:
*     - Initial version
* Description:
*     This project demonstrates communication with VS1053B mp3 codec.
*     Program reads one mp3 file from MMC and sends it to VS1053B for decoding
*     and playing.
*     MMC and MP3_SCI share Hardware SPI module.
* Test configuration:
*       MCU:             STM32F107VCT6
*                        http://www.st.com/internet/com/TECHNICAL_RESOURCES/TECHNICAL_LITERATURE/DATASHEET/CD00220364.pdf
*       Dev.Board:       Custom
*       modules:         VS1053B MP3 Player
*                        http://www.mikroe.com/eng/products/view/783/mp3-click/
*       Oscillator:      HS-PLL 72.0000 MHz, internal 8.0000 MHz RC
*       SW:              mikroC PRO for ARM
*                        http://www.mikroe.com/eng/products/view/228/mikroc-pro-for-arm/
* NOTES:
*     - Make sure that MMC card is properly formatted (to FAT32)
*       before testing it on this example.
*     - Make sure that MMC card contains appropriate mp3 file ( sound.mp3 ).
**************************************************************************************************/

/**************************************************************************************************
* CODEC V1053E connections
**************************************************************************************************/
// extern connection declarations
// MP3 Codec Connections
extern sfr sbit MP3_CS;
extern sfr sbit MP3_RST;
extern sfr sbit BSYNC;
extern sfr sbit DREQ;
//LED connection
extern sfr sbit LED;
extern sfr sbit Mmc_Chip_Select;

// external funsctions from MP# driver
extern void MP3_SCI_Read(char start_address, char words_count, unsigned int *data_buffer);
extern void MP3_SCI_Write(char address, unsigned int data_in);
extern void MP3_SDI_Write_32(char *data_);
extern void MP3_SDI_Write(char data_);
extern void MP3_Set_default_Mode();
extern void MP3_Set_Volume(char left, char right);
extern void MP3_Reset_Time();
extern void MP3_Get_Decode_Time(unsigned int *time);
extern void VsSineTest(void);